# This spec modified to have mod_arches (build kernel modules
# for) and package_arches (to build the main drbd package for)
# instead of auxarches by the CentOS-4 devel team. 

#%define auxarches i586 i686
%define mod_arches i586 i686 x86_64 ppc ppc64 s390 s390x sparc alpha
%define package_arches i386 x86_64 ppc s390 s390x sparc alpha
 
# "uname -r" output of the kernel to build for, the running one
# if none was specified with "--define 'kernelversion <uname -r>'"
%{!?kernelversion: %{expand: %%define kernelversion %(uname -r)}}
%{!?kdir: %{expand: %%define kdir /lib/modules/%{kernelversion}/build}}

%define kversion %(echo "%{kernelversion}" | sed -e 's|-.*||')
%define krelease %(echo "%{kernelversion}" | sed -e 's|.*-||')

#Modified (CentOS-4) the below line to include hugemem kernel
#%define kernelversion_req %(echo "%{kernelversion}" | sed -e 's|smp||')
%define kernelversion_req %(echo "%{kernelversion}" | sed -e 's|smp||' | sed -e 's|hugemem||')

Name: drbd
Summary: Distributed Redundant Block Device driver for Linux
Version: 0.7.14
Release: 1.centos4
Source: %{name}-%{version}.tar.gz
Source1: modsign.sh
Source2: mod-extract.sh
License: GPL
ExclusiveOS: linux
Group: System Environment/Kernel
Requires: kernel
Provides: %{name}
URL: http://www.drbd.org/ 
BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: bison groff flex gnupg binutils gzip

%ifarch %{mod_arches}
%define _use_internal_dependency_generator 0
%define __find_provides /usr/lib/rpm/redhat/find-kmod-provides.sh
%define __find_requires %{nil}
%endif

%description
Drbd is a distributed replicated block device. It mirrors a
block device over the network to another machine. Think of it
as networked raid 1. It is a building block for setting up
high availability (HA) clusters.

Authors:
--------
    Philipp Reisner <philipp.reisner@linbit.com> - Primary Author
    Lars Ellenberg  <l.g.e@web.de>

%ifarch %{mod_arches}
%package -n kernel-module-drbd-%{kernelversion}
Summary: Kernel driver for DRBD.
Group: System Environment/Kernel
Requires: %{name} = %{version}, /sbin/depmod
Provides: kernel-module-drbd = %{version}-%{release}
BuildRequires: kernel-devel = %{kernelversion_req}
BuildRequires: kernel-smp-devel = %{kernelversion_req}

%ifarch i686
BuildRequires: kernel-hugemem-devel = %{kernelversion_req}
%endif

%description -n kernel-module-drbd-%{kernelversion}
This module is the kernel-dependant driver for DRBD.  This is split out so
that multiple kernel driver versions can be installed, one for each
installed kernel.

This module is built for the %{kernelversion} kernel on %{_target_cpu}.
%endif

%prep
%setup

%ifarch %{mod_arches}
echo "Building DRBD module for %{kernelversion_req}"
cp -f %{_sourcedir}/modsign.sh %{_sourcedir}/mod-extract.sh .

test -d %{kdir}/.
test $(echo -e "#include <linux/version.h>\ndrbd_kernel_release UTS_RELEASE" |
      gcc -nostdinc -E -P -I%{kdir}/include - |
      sed -ne 's/^drbd_kernel_release "\(.*\)".*/\1/p') = %{kernelversion}
%endif

%build
echo kernelversion=%{kernelversion}
echo kversion=%{kversion}
echo krelease=%{krelease}
[ -n $RPM_BUILD_ROOT -a "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
mkdir -p %{buildroot}

make clean
# note: MANDIR is not used anywhere in the makefiles
#       maybe this should be changed

%ifarch %{package_arches}
make tools doc PREFIX=%{buildroot}/ MANDIR=%{_mandir}
%endif

%ifarch %{mod_arches}
pushd drbd
make all KDIR=%{kdir}
popd
%endif

%install
%ifarch %{package_arches}
make install-tools PREFIX=%{buildroot}/ MANDIR=%{_mandir}
%endif

%ifarch %{mod_arches}
pushd drbd
mv .kernel.config.gz k-config-%{kernelversion}.gz
make install PREFIX=%{buildroot}/ MANDIR=%{_mandir} KDIR=%{kdir}
popd

for i in `find $RPM_BUILD_ROOT -name *.ko`; do
        sh ./modsign.sh $i
        mv -f $i.signed $i
done

find $RPM_BUILD_ROOT -name "*.ko" -type f  | xargs chmod u+x
%endif

%ifarch %{package_arches}
FILELIST="%{_builddir}/%{name}-%{version}/file.list"
cd %{buildroot}
#
# this is because /etc/init.d != /etc/rc.d != /etc/rc.d/init.d ...
# you may want to edit this, or the file list below ;)
#
find etc/ -name drbd -printf "/%p\n" > "$FILELIST"
# on suse/united we have additionally:
test -e sbin/rcdrbd && echo "/sbin/rcdrbd" >> "$FILELIST"

## If I only wanted to include the module, not all the directories
## I'd then say  %files -n kernel%{?ksmp}-module-drbd -f $FILELIST.mod below
#find lib/ -name "drbd.*" -printf "/%p\n" > "$FILELIST.mod"

#
# and I only want to install a hint to the example conf
#
cat <<___ > etc/drbd.conf
#
# please have a a look at the example configuration file in
# %{_docdir}/drbd.conf
#
___

%endif

%clean
[ -n $RPM_BUILD_ROOT -a "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%ifarch %{package_arches}
%files -f %{_builddir}/%{name}-%{version}/file.list
%defattr(755,root,root)
/sbin/drbdsetup
/sbin/drbdadm
/etc/ha.d/resource.d/drbddisk

%defattr(644,root,root)
%config(noreplace) /etc/drbd.conf

%defattr(-,root,root)
%{_mandir}/man8/drbd.8.gz
%{_mandir}/man8/drbdsetup.8.gz
%{_mandir}/man8/drbdadm.8.gz
%{_mandir}/man8/drbddisk.8.gz
%{_mandir}/man5/drbd.conf.5.gz
%doc scripts/drbd.conf
%doc COPYING
%doc README
%doc file.list
%endif

%ifarch %{mod_arches}
%files -n kernel-module-drbd-%{kernelversion}
%defattr(-,root,root)
/lib/modules/%{kernelversion}/
%doc drbd/k-config-%{kernelversion}.gz
%endif

%ifarch %{package_arches}
%post
if [ $1 -eq 1 ]; then
    /sbin/chkconfig --add drbd
fi

%preun
if [ $1 -eq 0 ]; then
    /sbin/service drbd stop >/dev/null 2>&1 || :
fi

lsmod | grep drbd > /dev/null 2>&1
if [ $? -eq 0 ]; then
	/sbin/rmmod drbd
fi

if [ $1 -eq 0 ]; then
	/sbin/chkconfig --del drbd
fi
%endif

%ifarch %{mod_arches}
%post -n kernel-module-drbd-%{kernelversion}
uname -r | grep BOOT ||
/sbin/depmod -a -F /boot/System.map-%{kernelversion} %{kernelversion} >/dev/null 2>&1 || true

%postun -n kernel-module-drbd-%{kernelversion}
/sbin/depmod -a -F /boot/System.map-%{kernelversion} %{kernelversion} >/dev/null 2>&1 || true
%endif

%changelog
* Tue Sep  6 2005 Johnny Hughes <johnny@centos.org>
- used the spec file from tinysofa.org
- modifed the spec for centos
- Upgraded to version drbd-0.7.13 and backed out all
  tinysofa patches
- redefined auxarches to be mod_arches and added 
  package_arches to define 2 sets of arches (one for
  kernel modules, one for the main package).  This was
  required because some arches (x86_64, s390, s390x,
  etc.) will need to be in both groups.
- added the ability to build kernel modules for the
  hugemem kernel

* Thu Jul 22 2004 Omar Kilani <omar at tinysofa dot org>
- Do not enable service by default.
- Rewrite spec file.
- Rewrite init script.

* Fri Jul 16 2004 10:13:33 +0200 Philipp Reisner <phil@linbit.com>
- drbd (0.7.0-1)
  FIXME write changelog :^)

